@@ -7,3 +7,7 @@
 """This module contains various data types and associated I/O routines,
 models, constants, and other data-like things used throughout ``fslpy``.
 """
+
+
+from .utils import (guessType,  # noqa
+                    makeWriteable)
