@@ -41,17 +41,16 @@ _atlases = cache.Cache()
 def _get_atlas(atlasID, res, summary=False):
     atlas = _atlases.get((atlasID, res, summary), default=None)
     if atlas is None:
-        if summary or atlasID in ('talairach', 'striatum-structural',
-                                  'jhu-labels', 'smatt'):
-            kwargs = {}
-        else:
-            kwargs = {'loadData'  : False,
-                      'calcRange' : False}
-
         atlas = fslatlases.loadAtlas(atlasID,
                                      loadSummary=summary,
-                                     resolution=res,
-                                     **kwargs)
+                                     resolution=res)
+
+        # We need some atlases to be loaded into memory,
+        # so we can use boolean-mask-based indexing
+        if summary or atlasID in ('talairach', 'striatum-structural',
+                                  'jhu-labels', 'smatt'):
+            atlas.data
+
         _atlases.put((atlasID, res, summary), atlas)
 
     return atlas
